@@ -3,6 +3,8 @@ from PythUnity import Functions
 import copy
 import pygame
 import types
+import numba as nb
+import numpy as np
 class Object:
   def __init__(self, rect, image, onClick = None, onDrag = None, onClickOff = None, onScroll = None, enableDragOff = False, clickGroup = 0):
     self.__destroyed = False
@@ -10,19 +12,21 @@ class Object:
     self.__children = []
     self.__variables = {}
     self.__image = None
+    self.__transformedImage = None
     self.__text = None
     self.__color = None
     self.__components = []
     self.__clickGroup = clickGroup#not implemented yet
     self.__velocity = (0, 0)
     self.__index = None
+    self.__rect = None
+    self.rect = rect
     if(type(image) is tuple):
       self.color = image
     elif(type(image) is String):
       self.text = copy.deepcopy(image)
-    else:
+    elif(type(image) is pygame.Surface):
       self.image = image
-    self.rect = rect
     if onClick != None or onDrag != None or onScroll != None:
       self.__button = Button(onClick, onDrag, onClickOff, onScroll, enableDragOff)
     else:
@@ -33,18 +37,22 @@ class Object:
     #print("////////////")
   #####
   @property
+  def rect(self):
+      return self.__rect
+  @rect.setter
+  def rect(self, value):
+    Functions.TypeCheck(value, Rect, "rect")
+    self.__rect = value
+    self.__rect._Rect__owner = self
+    TransformImage(self)
+  @property
   def image(self):
     return self.__image
   @image.setter
   def image(self, value):
     Functions.TypeCheck(value, pygame.Surface, "image")
     self.__image = value
-    ratio = self.__image.get_size()
-    max = ratio[0]
-    if(max < ratio[1]):
-        max = ratio[1]
-    ratio = (int(1000.0 * ratio[0] / max), int(1000.0 * ratio[1] / max))
-    self.__image = pygame.transform.scale(self.__image, ratio)
+    TransformImage(self, changeColor=True)
   @property
   def destroyed(self):
     return self.__destroyed
@@ -81,6 +89,12 @@ class Object:
   @variables.setter
   def variables(self, value):
     Functions.Err("Cant set Object.variables, add each variable individualy")
+  @property
+  def transformedImage(self):
+    return self.__transformedImage
+  @transformedImage.setter
+  def transformedImage(self, value):
+    Functions.Err("Cant set Object.transformedImage")
   ##
   @property
   def text(self):
@@ -95,7 +109,13 @@ class Object:
   @color.setter
   def color(self, value):
     Functions.TypeCheck(value, [tuple, type(None)], "color")
-    self.__color = value
+    if(value == None or len(value) == 4):
+        self.__color = (float(value[0]), float(value[1]), float(value[2]), float(value[3]))
+    elif(len(value) == 3):
+        self.__color = (float(value[0]), float(value[1]), float(value[2]), 255.0)
+    else:
+        Functions.Err("Object.color must have a length of 3 or 4 in RGBA or RGB format")
+    TransformImage(self, changeColor=True)
   @property
   def clickGroup(self):
       return self.__clickGroup
@@ -170,15 +190,16 @@ class Object:
     return children
   def Copy(self):
     self.__Throw("Object.Copy")
-    CopyHelp(self)
+    oldParent = self.parent
     parChildren = self.GetParentChildren()
+    CopyHelp(self)
     copied = copy.deepcopy(self)
     copied._Object__index = len(parChildren)
     parChildren.append(copied)
-    copied.__parent = self.__parent
+    copied._Object__parent = oldParent
     copied.Move(self.index + 1)
-    CopyUnHelp(self)
-    CopyUnHelp(copied)
+    CopyUnHelp(self, oldParent)
+    CopyUnHelp(copied, oldParent)
     CopyHelp2(copied)
     return copied
   def Destroy(self):
@@ -308,24 +329,136 @@ class String:
   def backgroundColor(self, value):
     Functions.TypeCheck(value, [tuple, type(None)], "backgroundColor", "String")
     self.__backgroundColor = value
+
+class Rect: #need to use @property so cant use pygame.rect
+    def __init__(self, left, top, width, height):
+        self.__owner = None
+        self.__left = None
+        self.__top = None
+        self.__width = None
+        self.__height = None
+        self.left = left
+        self.top = top
+        self.width = width
+        self.height = height
+    @property
+    def left(self):
+        return self.__left
+    @left.setter
+    def left(self, value):
+      Functions.TypeCheck(value, [float, int], "left", "Rect")
+      self.__left = int(value)
+      if(self.__owner != None):
+        TransformImage(self.__owner)
+    @property
+    def top(self):
+        return self.__top
+    @top.setter
+    def top(self, value):
+      Functions.TypeCheck(value, [float, int], "top", "Rect")
+      self.__top = int(value)
+      if(self.__owner != None):
+        TransformImage(self.__owner)
+    @property
+    def width(self):
+        return self.__width
+    @width.setter
+    def width(self, value):
+      Functions.TypeCheck(value, [float, int], "width", "Rect")
+      self.__width = int(value)
+      if(self.__owner != None):
+        TransformImage(self.__owner)
+    @property
+    def height(self):
+        return self.__height
+    @height.setter
+    def height(self, value):
+      Functions.TypeCheck(value, [float, int], "height", "Rect")
+      self.__height = int(value)
+      if(self.__owner != None):
+        TransformImage(self.__owner)
+    ######
+    def __getitem__(self, i):
+      options = RectItemHelp(self, i)
+      return getattr(self, options[i])
+    def __setitem__(self, i, newvalue): 
+      if(type(newvalue) is not int and type(newvalue) is not float):
+        Functions.Err("in PythUnity.Rect[index] = newValue, newValue must be a " + str(int) + " or " + str(float) + " not " + str(type(newvalue)))
+      options = RectItemHelp(self, i)
+      attr = setattr(self, options[i], newvalue)
+    ######
+    def ToPygameRect(self):
+        return pygame.Rect(self.left, self.top, self.width, self.height)
+    def Copy(self):
+        return Rect(self.left, self.top, self.width, self.height)
+
+def RectItemHelp(self, i):
+  options = ["left", "top", "width", "height"]
+  if(type(i) is not int):
+    Functions.Err("in PythUnity.Rect[index], index must be a " + str(int) + " not " + str(type(i)))
+  if(i > 4 or i < 0):
+    Functions.Err("in PythUnity.Rect[index], index must be between values 0 and " + str(len(options)))
+  return options
 def CopyHelp(self):
   if(self.image != None):
     self._Object__image = (pygame.image.tostring(self._Object__image, 'RGBA'), self._Object__image.get_size())
+    self._Object__transformedImage = (pygame.image.tostring(self._Object__transformedImage, 'RGBA'), self._Object__transformedImage.get_size())
+  self.rect._Rect__owner = None
+  self._Object__parent = None
   for i in self.children:
     CopyHelp(i)
 
-def CopyUnHelp(self):
+def CopyUnHelp(self, parent):
   if(self._Object__image != None):
     self._Object__image = pygame.image.fromstring(self._Object__image[0], self._Object__image[1], 'RGBA')
+    self._Object__transformedImage = pygame.image.fromstring(self._Object__transformedImage[0], self._Object__transformedImage[1], 'RGBA')
+  self.rect._Rect__owner = self
+  self._Object__parent = parent
   for i in self.children:
-    CopyUnHelp(i)
+    CopyUnHelp(i, self)
 def CopyHelp2(self):
-  for att in dir(self):
+  atts = dir(self)
+  for att in atts:
     attObj = getattr(self, att)
     if(att[0] != "_" or att[1] == "O"):#if its a _Object__ atribute still copy
         attType = type(attObj)
-        if(attType is not types.MethodType and attType is not list and attType is not type(None) and attType is not Object and attType is not pygame.Surface):
-            attObj = copy.deepcopy(attObj)
+        if(attType is not types.MethodType and attType is not list and attType is not type(None) and attType is not Object and attType is not pygame.Surface and attType is not Rect):
+            if(("_Object__" + att) not in atts):
+              setattr(self, att, copy.deepcopy(attObj))
   for i in self.children:
     CopyHelp2(i)
 
+def TransformImage(self, changeColor = False):
+  if(self.image != None):
+      ratio = self.image.get_size()
+      if(type(self.color) is not type(None) and changeColor):
+          #self._Object__transformedImage = pygame.Surface((ratio[0], ratio[1]))
+          #print("a " + str(ratio[0]*ratio[1]))
+          #array = MultColor(np.array(self.color), pygame.PixelArray(self.image), self.image, self.image.get_size())
+          #print("z")
+          #pygame.surfarray.blit_array(self._Object__transformedImage, array)
+          #print("z2")
+          #commented section too slow so replaced it till later
+          self._Object__transformedImage = self.image
+      elif(type(self.color) is type(None)):
+          self._Object__transformedImage = self.image
+      ratio = self.image.get_size()
+      max = ratio[0]
+      if(max < ratio[1]):
+        max = ratio[1]
+      ratio = (float(ratio[0] / max), float(ratio[1] / max))
+      ratio = (int(ratio[0] * self.rect.width), int(ratio[1] * self.rect.height))
+      self._Object__transformedImage = pygame.transform.scale(self._Object__transformedImage, ratio)
+  else:
+    self._Object__transformedImage = None
+@nb.jit(forceobj=True)
+def MultColor(color, array, image, rect):
+  multColor = (color[0]/255, color[1]/255, color[2]/255, color[3]/255)
+  width = rect[0]
+  height = rect[1]
+  arr = np.empty((width, height), dtype=float)
+  for x in nb.prange(width):
+    for y in nb.prange(height):
+       newColor = image.unmap_rgb(array[x, y])
+       arr[x, y] = image.map_rgb((newColor[0] * multColor[0], newColor[1] * multColor[1], newColor[2] * multColor[2], newColor[3] * multColor[3]))
+  return arr
\ No newline at end of file
